@@ -13,7 +13,7 @@ has 'url' => ( isa => 'Mojo::URL', is => 'ro', lazy_build => 1 );
 sub _build_url {
     my $self = shift;
 
-    my $url = $self->service_url;
+    my $url = $self->service_url->clone;
     $url->path ( '/weatherapi/textlocation/1.0/' );
     $url->query( latitude => $self->lat, longitude => $self->lon, language => $self->lang );
 
